Deserializer
This module contains the deserialization logic for the library. It is used to deserialize bytes to a custom type.
To use the deserializer, you need to call the from_bytes function which takes in
the bytes and a type. The type must implement the Deserialize trait from the serde library.
It returns a Result with the deserialized data or an error.
Functions
- from_
bytes - The function to deserialize (serialized) bytes back into data.
Tmust implement theDeserializetrait from theserdelibrary.bytesis the data to be deserialized. It returns a Result with the deserialized data or an error.